---
name: Bug report
about: Create a report to help us improve
title: ""
labels: bug
assignees: ""
---

**Describe the bug**
A clear and concise description of what the bug is.
what is the current behavior

**What is the expected behavior?**
What is the motivation / use case for changing the behavior?

**To Reproduce**
Steps to reproduce the behavior:
Please provide a minimal working example of the bug if possible.

**Environment (please complete the following information):**

- Operating System: [all | Windows | Mac | Linux]
- Language Extension: [all | Python | MATLAB | Java | Octave| C | C++]
- what compiler or setup process did you use
- HELICS version: <!-- 1.3.0 (07-31-18) -->

```bash
$ helics_app --version
```

**Additional context and information**
(e.g. detailed explanation, stacktraces, related issues, suggestions how to fix, links for us to have context, eg. stackoverflow, gitter, etc)
